// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
angular.module('motorApp', ['ionic', 'ngCordova', 'motorApp.services', 'motorApp.controllers', 'motorApp.directives', 'ngStorage', 'angular-cache', 'pascalprecht.translate', 'ui.slider'])

    .config(function ($stateProvider, $urlRouterProvider, $httpProvider, $provide, CacheFactoryProvider, $translateProvider, $ionicConfigProvider) {
        angular.extend(CacheFactoryProvider.defaults, {maxAge: 15 * 60 * 1000});

        $ionicConfigProvider.views.maxCache(0);

        $ionicConfigProvider.scrolling.jsScrolling(false);

        $stateProvider
            .state('filters', {
                controller: 'FiltersCtrl',
                url: '/',
                templateUrl: 'partials/_filters.html'
            })
            .state('main', {
                url: "/main",
                abstract: true,
                templateUrl: "partials/side-screens.html"
            })
            .state('main.list', {
                url: "/list",
                views: {
                    'left': {
                        templateUrl: "partials/sides/side-filters.html",
                        controller: "SideFiltersCtrl"
                    },
                    'right': {
                        templateUrl: "partials/sides/side-sorters.html",
                        controller: "SideSortersCtrl"
                    },
                    'center': {
                        controller: 'ListCtrl',
                        templateUrl: "partials/list.html",
                        resolve: {
                            loading: function () {
                                return false;
                            }
                        }
                    }
                }
            })
            .state('main.details', {
                url: "/details",
                views: {
                    'center': {
                        controller: 'DetailsCtrl',
                        templateUrl: "partials/details.html",
                        resolve: {
                            loading: function () {
                                return false;
                            }
                        }
                    }
                }
            });

        $provide.factory('PTDealersHttpInterceptor', function ($q, $rootScope, $injector) {

            //Declare $http provider to inject manually
            var $http;

            return {
                // On request success
                request: function (config) {
                    //console.log(config); // Contains the data about the request before it is sent.

                    $rootScope.$broadcast('loading:show');
                    // Return the config or wrap it in a promise if blank.
                    return config || $q.when(config);
                },

                // On request failure
                requestError: function (rejection) {
                    // console.log(rejection); // Contains the data about the error on the request.

                    //Wait until all requests are complete to hide loader
                    $http = $http || $injector.get('$http');
                    if ($http.pendingRequests.length < 1) {
                        $rootScope.$broadcast('loading:hide');
                    }

                    //$rootScope.$broadcast('server:down');

                    // Return the promise rejection.
                    return $q.reject(rejection);
                },

                // On response success
                response: function (response) {
                    //console.log(response); // Contains the data from the response.

                    //Wait until all requests are complete to hide loader
                    $http = $http || $injector.get('$http');
                    if ($http.pendingRequests.length < 1) {
                        $rootScope.$broadcast('loading:hide');
                    }

                    // Return the response or promise.
                    return response || $q.when(response);
                },

                // On response failture
                responseError: function (rejection) {
                    //console.log(rejection); // Contains the data about the error.

                    //Wait until all requests are complete to hide loader
                    $http = $http || $injector.get('$http');
                    if ($http.pendingRequests.length < 1) {
                        $rootScope.$broadcast('loading:hide');
                    }

                    //Set invalid Session
                    if (rejection.status == 401) {
                        $rootScope.$broadcast('user:unauthorized');
                    }

                    //Set invalid Session
                    if (rejection.status == 500) {
                        $rootScope.$broadcast('server:down');
                    }

                    // Return the promise rejection.
                    return $q.reject(rejection);
                }
            };
        });

        $httpProvider.interceptors.push('PTDealersHttpInterceptor');

        $translateProvider.translations('es', {

            //headers & titles
            MAIN_FILTER_TITLE: "¿Qué vehículo buscas?",

            //buttons labels
            BTN_CONTINUE: "Continuar",

            //filters labels
            MILEAGE: "Kilometraje",
            YEAR: "Año",
            PRICE: "Precio",
            LAST_DIGIT: "Último dígito",
            CITY: "Ciudad",
            TYPE: "Tipo",
            SUBTYPE: "Subtipo",
            MODEL: "Modelo",
            TRANSMISSION: "Transmisión",
            WINDOW: "Vidrios",
            PROVINCE: "Provincia",
            DRIVE: "Tracción",
            HEATING_SYSTEM: "Aire",
            FUEL: "Combustible",
            INTERIOR: "Tapizado",
            STEERING: "Dirección",
            BRAND: "Marca",
            COLOR: "Color",
            EQUIPMENT: "Equipamiento",
            EXTRA: "Extra",
            SPECIAL_TYPE: "Especial"

        });
        $translateProvider.preferredLanguage("es");
        $translateProvider.fallbackLanguage("es");

    })

    .run(function ($ionicPlatform, $cordovaSplashscreen, $rootScope, SettingsService, $ionicLoading, PTService, $location, $http, $localStorage) {
        $ionicPlatform.ready(function () {
            // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
            // for form inputs)
            if (window.cordova && window.cordova.plugins.Keyboard) {
                cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
                window.cordova.plugins.Keyboard.disableScroll(true);
            }
            if (window.StatusBar) {
                StatusBar.styleDefault();
            }
            $rootScope.analyticsCode = SettingsService.getAnalyticsCode();
            $rootScope.analyticsUserId = SettingsService.getAnalyticsUserId();
            if (typeof analytics !== 'undefined') {
                analytics.startTrackerWithId($rootScope.analyticsCode);
                analytics.trackView('Splash Screen ' + $rootScope.analyticsUserId);
            }
        });
        $rootScope.is_intro = true;
        //Listeners broadcast actions
        $rootScope.$on('loading:show', function () {
            if (!$rootScope.is_scrolling && !$rootScope.is_intro)
                $ionicLoading.show({template: '<ion-spinner></ion-spinner>'})
        })

        $rootScope.$on('loading:hide', function () {
            $ionicLoading.hide()
        })

        $rootScope.$on('server:down', function (response) {

            var alertPopup = $ionicPopup.alert({
                title: 'Error',
                template: 'Existió un problema al conectarse a nuestros servidores, por favor intenta más tarde'
            });

        });

        var orientation = (window.screen.width > window.screen.height) ? 0 : 1;

        var deviceWidth = orientation == 1 ? window.screen.width : window.screen.height;

        /*
         if (isAndroid && window.devicePixelRatio) {
         deviceWidth = deviceWidth / window.devicePixelRatio;
         }
         */

        $rootScope.deviceWidth = deviceWidth;

        $rootScope.params = {
            'ORDER_BY': 'PUBLISHED_AT',
            'SIZE': 6
        };
        var filter_types = [];
        $http.get('config/settings.json').then(function (response) {
            $localStorage.settings = response.data;
            PTService.searchVehicles($rootScope.params).then(function (response) {
                $rootScope.response = response;
                $rootScope.items_list = response.data.data.result_set;
                $rootScope.result_filter_types = response.data.data.filter_types;

                for (var i = 0; i < $rootScope.result_filter_types.length; i++) {
                    filter_types[$rootScope.result_filter_types[i].name] = $rootScope.result_filter_types[i];

                    for (var j = 0; j < $rootScope.result_filter_types[i].filters.length; j++) {
                        if ($rootScope.result_filter_types[i].filters[j].status == true) {
                            filter_types[$rootScope.result_filter_types[i].name].selected = $rootScope.result_filter_types[i].filters[j];
                        }
                    }
                }
                $rootScope.dealer_tag = SettingsService.getDealerTag();
                $rootScope.filter_types = filter_types;
                $location.path('/');
                setTimeout(function () {
                    $cordovaSplashscreen.hide();
                }, 500);
            });
        });

        $rootScope.default = {};
        $rootScope.default.type = {name: 'Tipo de Vehículo', icon: '', status: false};
        $rootScope.default.brand = {name: 'Marca', icon: '', status: false};
        $rootScope.default.model = {name: 'Modelo', icon: '', status: false};

        $rootScope.currentOrder = {};
        $rootScope.currentOrder.order = {name: 'Destacado', code: 'HIGHLIGHTED'};
        $rootScope.currentOrder.type = false;
    });
