'use strict';

angular.module('motorApp.controllers', [])

    // FILTERS CONTROLLER

    .controller('FiltersCtrl', function ($scope, $rootScope, $ionicPlatform, $ionicModal, PTService, $location, $cordovaSplashscreen) {
        $rootScope.is_intro = false;
        $ionicPlatform.ready(function () {
            if (typeof analytics !== 'undefined') {
                analytics.trackView('Filter Screen ' + $rootScope.analyticsUserId);
            }
        });

        $scope.items = $rootScope.items_list;

        $scope.item_slides = [];

        $scope.largeDevice = function () {
            return $rootScope.deviceWidth > 767;
        }

        var j = 0;
        $scope.item_slides[0] = [];

        if ($scope.largeDevice()) {
            for (var i = 0; i < $scope.items.length; i++) {
                $scope.item_slides[j].push($scope.items[i]);
                if (i % 2 == 1 && i < $scope.items.length - 1) {
                    $scope.item_slides[++j] = [];
                }
            }
        }
        else {
            for (var i = 0; i < $scope.items.length; i++) {
                $scope.item_slides[j].push($scope.items[i]);
                if (i < $scope.items.length - 1) {
                    $scope.item_slides[++j] = [];
                }
            }

        }

        $scope.default.type = $rootScope.default.type;
        $scope.default.brand = $rootScope.default.brand;
        $scope.default.model = $rootScope.default.model;

        $scope.dealer_tag = $rootScope.dealer_tag;

        $scope.filterModal = null;

        $scope.filter_types = $rootScope.filter_types;


        if ($scope.filter_types['TYPE'].filters.length > 0) {
            $scope.filter_types['TYPE'].filters[0].status = true;
            $scope.filter_types['TYPE'].selected = $scope.filter_types['TYPE'].filters[0];
            $scope.type_disabled = false;
        } else {
            $scope.type_disabled = true;
        }


        $scope.search = {};

        $scope.showDetails = function (item_id) {

            var image_params = {
                'image_width': 800,
                'image_height': 600,
                'image_crop': true
            };

            PTService.getVehicleDetails(item_id, image_params).then(function (response) {

                $rootScope.vehicle = response.data.data;

                var attributes = response.data.data.attributes;
                var lookup = {};

                attributes.forEach(function (el) {
                    lookup[el.attribute_type] = el;
                });

                $rootScope.vehicle.attributes = lookup;

                $location.path('/main/details');
            });

        };

        $scope.loadList = function () {

            if ($scope.filter_types['TYPE'] != null && $scope.filter_types['TYPE'].selected != null) {

                $scope.type_name = ($scope.filter_types['TYPE'] != null && $scope.filter_types['TYPE'].selected != null) ? $scope.filter_types['TYPE'].selected.name : null;
                $scope.brand_name = ($scope.filter_types['BRAND'] != null && $scope.filter_types['BRAND'].selected != null) ? $scope.filter_types['BRAND'].selected.name : null;
                $scope.model_name = ($scope.filter_types['MODEL'] != null && $scope.filter_types['MODEL'].selected != null) ? $scope.filter_types['MODEL'].selected.name : null;

                $rootScope.params = {
                    'TYPE[]': [$scope.type_name]
                }

                if ($scope.brand_name != null) {
                    $rootScope.params['BRAND[]'] = [$scope.brand_name];

                    if ($scope.model_name != null) {
                        $rootScope.params['MODEL[]'] = [$scope.model_name];

                    }
                }

                $rootScope.params['PAGE'] = 1;

                $rootScope.params['ORDER_BY'] = $rootScope.currentOrder.order.code;
                $rootScope.params['SIZE'] = 20;
                $rootScope.params['DESC'] = true;

                PTService.searchVehicles($rootScope.params).then(function (response) {
                    $rootScope.response = response;
                    $rootScope.items_list = response.data.data.result_set;
                    $rootScope.result_filter_types = response.data.data.filter_types;


                    for (var i = 0; i < $rootScope.result_filter_types.length; i++) {

                        $scope.filter_types[$rootScope.result_filter_types[i].name] = $rootScope.result_filter_types[i];

                        for (var j = 0; j < $rootScope.result_filter_types[i].filters.length; j++) {
                            if ($rootScope.result_filter_types[i].filters[j].status == true) {
                                $scope.filter_types[$rootScope.result_filter_types[i].name].selected = $rootScope.result_filter_types[i].filters[j];
                            }
                        }
                    }

                    $rootScope.filter_types = $scope.filter_types;

                    if ($scope.filterModal != null) {
                        $scope.filterModal.hide();
                    }
                    $location.path('/main/list');

                });

            } else {
                var alertPopup = $ionicPopup.alert({
                    title: 'Error',
                    template: 'Debe seleccionar un tipo de vehículo antes de realizar la búsqueda.'
                });
            }

        }

        $scope.currentFilter = "TYPE";

        $scope.showFilterModal = function (filter) {

            $rootScope.params = {};

            //$rootScope.params['TYPE[]'] = $rootScope.params['BRAND[]'] = $rootScope.params['MODEL[]'] = null;

            if ($scope.filterModal == null) {
                $ionicModal.fromTemplateUrl('partials/modals/_filter.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    $scope.filterModal = modal;

                    $scope.currentFilter = filter;

                    switch (filter) {
                        case 'BRAND' :
                            $rootScope.params['TYPE[]'] = $scope.filter_types['TYPE'].selected.name;
                            break;
                        case 'MODEL' :
                            $rootScope.params['TYPE[]'] = $scope.filter_types['TYPE'].selected.name;
                            $rootScope.params['BRAND[]'] = $scope.filter_types['BRAND'].selected.name;
                            break;
                    }

                    $scope.openFilterModal($rootScope.params);

                });

            } else {
                $scope.currentFilter = filter;

                switch (filter) {
                    case 'BRAND' :
                        $rootScope.params['TYPE[]'] = $scope.filter_types['TYPE'].selected.name;
                        break;
                    case 'MODEL' :
                        $rootScope.params['TYPE[]'] = $scope.filter_types['TYPE'].selected.name;
                        $rootScope.params['BRAND[]'] = $scope.filter_types['BRAND'].selected.name;
                        break;
                }

                $scope.openFilterModal($rootScope.params);
            }
        };

        $scope.openFilterModal = function (params) {

            PTService.searchVehicles(params).then(function (response) {

                var data = response.data.data.filter_types;
                $scope.filter_typesMap = {};

                data.forEach(function (el) {
                    $scope.filter_typesMap[el.name] = el.filters;
                });

                $scope.filter_items = $scope.filter_typesMap[$scope.currentFilter];

                $scope.filterModal.show();

            });

        };

        $scope.closeFilterModal = function () {
            $scope.filter_items = [];
            $scope.filterModal.hide();
        };
        //Cleanup the modal when we're done with it!
        $scope.$on('$destroy', function () {
            if ($scope.filterModal != null) {
                $scope.filterModal.hide();
            }
        });
        // Execute action on hide modal
        $scope.$on('modal.hidden', function () {
            // Execute action
        });
        // Execute action on remove modal
        $scope.$on('modal.removed', function () {
            // Execute action
        });

        $scope.setFilter = function (filter) {
            $scope.filter_types[$scope.currentFilter] = $scope.filter_types[$scope.currentFilter] || {};
            $scope.filter_types[$scope.currentFilter].selected = filter;
            $scope.filter_types[$scope.currentFilter].selected.status = true;

            //clean dependant filters
            switch ($scope.currentFilter) {
                case 'TYPE' :
                    $scope.filter_types['BRAND'] = null;
                    $scope.filter_types['MODEL'] = null;
                    break;
                case 'BRAND' :
                    $scope.filter_types['MODEL'] = null;
                    break;

            }

            $scope.search = {};
            $scope.closeFilterModal();

        };

        //functions to show and hide features in filters

        $scope.filterDisabled = function (filter, parent_filter) {
            return ($scope.filter_types[parent_filter] == null || $scope.filter_types[parent_filter].selected == null);
        };

        $scope.filterSelected = function (filter) {
            return $scope.filter_types[filter] != null && $scope.filter_types[filter].selected != null;
        };

        $scope.resetFilters = function (filter) {

            switch (filter) {
                case 'BRAND' :
                    $scope.filter_types['BRAND'] = null;
                    $scope.filter_types['MODEL'] = null;
                    break;
                case 'MODEL' :
                    $scope.filter_types['MODEL'] = null;
                    break;
                default :
                    $scope.filter_types['TYPE'] = null;
                    $scope.filter_types['BRAND'] = null;
                    $scope.filter_types['MODEL'] = null;
                    break;
            }
        };

    })

    // [END] FILTERS CONTROLLER

    // LIST CONTROLLER

    .controller('ListCtrl', function ($scope, $stateParams, $location, $rootScope, $ionicModal, PTService, $ionicPlatform) {
        $ionicPlatform.ready(function () {
            if (typeof analytics !== 'undefined') {
                analytics.trackView('List Screen ' + $rootScope.analyticsUserId);
            }
        });
        $scope.$on('$ionicView.enter', function () {

            $scope.items = $rootScope.items_list;
            $scope.filter_types = $rootScope.filter_types;

            $scope.currentOrder = $rootScope.currentOrder || 'HIGHLIGHTED';

            $scope.order_code = $scope.currentOrder.order.code;

            var type_name = ($scope.filter_types['TYPE'] != null && $scope.filter_types['TYPE'].selected != null) ? $scope.filter_types['TYPE'].selected.name : '';
            var brand_name = ($scope.filter_types['BRAND'] != null && $scope.filter_types['BRAND'].selected != null) ? $scope.filter_types['BRAND'].selected.name : '';
            var model_name = ($scope.filter_types['MODEL'] != null && $scope.filter_types['MODEL'].selected != null) ? $scope.filter_types['MODEL'].selected.name : '';

            $scope.header_title = (brand_name != '') ? brand_name + ' ' + model_name : "Todos los vehículos";

            $scope.subheader_title = $rootScope.response.data.total_items + " encontrados";

            $scope.leftMenuEnabled = function () {
                return true;
            }
            $scope.rightMenuEnabled = function () {
                return true;
            }
        });

        $scope.showDetails = function (item_id) {

            var image_params = {
                'image_width': 800,
                'image_height': 600,
                'image_crop': true
            };

            PTService.getVehicleDetails(item_id, image_params).then(function (response) {

                $rootScope.vehicle = response.data.data;

                var attributes = response.data.data.attributes;
                var lookup = {};

                attributes.forEach(function (el) {
                    lookup[el.attribute_type] = el;
                });

                $rootScope.vehicle.attributes = lookup;

                $location.path('/main/details');
            });

        };

        $scope.loadNextVehicles = function () {
            $rootScope.is_scrolling = true;

            $rootScope.params['PAGE'] = parseInt($rootScope.response.data.page) + 1;

            if ($rootScope.params['PAGE'] != -1) {

                PTService.searchVehicles($rootScope.params).then(function (response) {
                    $rootScope.response = response;

                    $rootScope.items_list = response.data.data.result_set;

                    $rootScope.items_list = $scope.items = $scope.items.concat($rootScope.items_list);

                    $rootScope.result_filter_types = response.data.data.filter_types;

                    $scope.$broadcast('scroll.infiniteScrollComplete');

                    $rootScope.is_scrolling = false;

                });

            }

            $scope.$on('$stateChangeSuccess', function () {
                $scope.loadNextVehicles();
            });
        }

        $scope.moreVehiclesCanBeLoaded = function () {
            return ( $rootScope.response.data.data != [] && parseInt($rootScope.response.data.page) < parseInt($rootScope.response.data.total_pages));
        }

    })

// [END] LIST CONTROLLER

// SIDE FILTER CONTROLLER

    .controller('SideFiltersCtrl', function ($scope, $rootScope, $location, PTService, $state, $ionicSideMenuDelegate, $ionicScrollDelegate, $ionicPopup, $ionicPlatform) {
        $ionicPlatform.ready(function () {
            if (typeof analytics !== 'undefined') {
                analytics.trackView('Side Filter Screen ' + $rootScope.analyticsUserId);
            }
        });
        $scope.default.type = $rootScope.default.type;
        $scope.default.brand = $rootScope.default.brand;
        $scope.default.model = $rootScope.default.model;

        $scope.main_filters = ["TYPE", "BRAND", "MODEL"];
        $scope.multiple_filters = ["PRICE", "MILEAGE", "YEAR"];

        $scope.filter_types = $rootScope.filter_types;

        console.log($scope.filter_types);

        $scope.show_advanced_filters = false;
        $scope.show_filters_box = true;
        $scope.show_filter_chooser = false;

        $scope.switch_btn_titles = ['Mostrar filtros avanzados', 'Ocultar filtros avanzados'];
        $scope.current_btn_title = $scope.switch_btn_titles[0];

        $scope.current_filter = 'TYPE';
        $scope.items = {};
        $scope.search = {};

        $scope.header_title = "Actualizar listado";

        $scope.price = {
            min: ($scope.filter_types['PRICE'] != null) ? $scope.filter_types['PRICE'].filters[0].name : '0',
            max: ($scope.filter_types['PRICE'] != null) ? $scope.filter_types['PRICE'].filters[1].name : '1000000'
        };

        $scope.price.current = ($rootScope.params['PRICE[]'] != null) ? $rootScope.params['PRICE[]'][1] : null;

        $scope.mileage = {
            min: ($scope.filter_types['MILEAGE'] != null) ? $scope.filter_types['MILEAGE'].filters[0].name : '0',
            max: ($scope.filter_types['MILEAGE'] != null) ? $scope.filter_types['MILEAGE'].filters[1].name : '1000000'
        };

        $scope.mileage.current = ($rootScope.params['MILEAGE[]'] != null) ? $rootScope.params['MILEAGE[]'][1] : null;

        var currentTime = new Date();
        var this_year = currentTime.getFullYear();

        $scope.year = {
            min: ($scope.filter_types['YEAR'] != null) ? $scope.filter_types['YEAR'].filters[0].name : '1900',
            max: ($scope.filter_types['YEAR'] != null) ? $scope.filter_types['YEAR'].filters[$scope.filter_types['YEAR'].filters.length - 1].name : this_year
        };

        $scope.year.current = ($rootScope.params['YEAR[]'] != null) ? $rootScope.params['YEAR[]'][1] : null;

        $scope.renderAdvancedFilter = function (filter_type) {
            console.log($scope.filter_types);
            console.log(filter_type);
            return (
            filter_type != null
            && filter_type.name != null
            && !_.find($scope.main_filters, function (key) {
                return filter_type.name == key;
            })
            && !_.find($scope.multiple_filters, function (key) {
                return filter_type.name == key;
            })
            );
        };

        $scope.loadList = function () {

            if ($scope.filter_types['TYPE'] != null && $scope.filter_types['TYPE'].selected != null) {

                $rootScope.params = {};
                $rootScope.params['PAGE'] = '1';

                $rootScope.params['ORDER_BY'] = $rootScope.currentOrder.order.code;

                //verify all current filters by added property 'selected'
                for (var i in $scope.filter_types) {
                    if ($scope.filter_types[i] != null && $scope.filter_types[i].selected != null) {
                        var filter_name = $scope.filter_types[i].name + '[]'
                        $rootScope.params[filter_name] = [$scope.filter_types[i].selected.name];
                    }
                }

                if ($scope.price.current != null) {
                    $rootScope.params['PRICE[]'] = [$scope.price.min, parseInt($scope.price.current)];
                }

                if ($scope.mileage.current != null) {
                    $rootScope.params['MILEAGE[]'] = [$scope.mileage.min, parseInt($scope.mileage.current)];
                }

                if ($scope.year.current != null) {
                    $rootScope.params['YEAR[]'] = [$scope.year.min, parseInt($scope.year.current)];
                }

                //call service to find all vehicles which match with selected filters
                PTService.searchVehicles($rootScope.params).then(function (response) {

                    $rootScope.response = response;

                    $rootScope.items_list = response.data.data.result_set;
                    $scope.result_filter_types = $rootScope.result_filter_types = response.data.data.filter_types;

                    for (var i = 0; i < $rootScope.result_filter_types.length; i++) {
                        $scope.filter_types[$rootScope.result_filter_types[i].name] = $rootScope.result_filter_types[i];
                        for (var j = 0; j < $rootScope.result_filter_types[i].filters.length; j++) {
                            if ($rootScope.result_filter_types[i].filters[j].status == true) {
                                $scope.filter_types[$rootScope.result_filter_types[i].name].selected = $rootScope.result_filter_types[i].filters[j];
                            }
                        }
                    }

                    $rootScope.filter_types = $scope.filter_types;

                    $state.go($state.current, {}, {reload: true});

                }, function (response) {
                    $rootScope.response = response;
                    $rootScope.items_list = {};
                    $scope.filter_types = {};

                    $state.go($state.current, {}, {reload: true});

                });

            } else {
                var alertPopup = $ionicPopup.alert({
                    title: 'Error',
                    template: 'Debe seleccionar un tipo de vehículo antes de realizar la búsqueda.'
                });
            }

        }

        $scope.switchAdvancedFilters = function (state) {

            $scope.show_advanced_filters = !state;
            $scope.current_btn_title = ($scope.show_advanced_filters == false) ? $scope.switch_btn_titles[0] : $scope.switch_btn_titles[1];

        }

        $scope.showFilterChooser = function (filter) {
            $scope.show_filters_box = false;
            $scope.header_title = $scope.current_filter = filter;

            if (filter == 'TYPE' || filter == 'BRAND' || filter == 'MODEL') {


                switch (filter) {
                    case 'TYPE' :
                        $rootScope.params['TYPE[]'] = $rootScope.params['BRAND[]'] = $rootScope.params['MODEL[]'] = null;
                        break;
                    case 'BRAND' :
                        $rootScope.params['TYPE[]'] = $scope.filter_types['TYPE'].selected.name;
                        $rootScope.params['BRAND[]'] = $rootScope.params['MODEL[]'] = null;
                        break;
                    case 'MODEL' :
                        $rootScope.params['TYPE[]'] = $scope.filter_types['TYPE'].selected.name;
                        $rootScope.params['BRAND[]'] = $scope.filter_types['BRAND'].selected.name;
                        $rootScope.params['MODEL[]'] = null;
                        break;
                }

                PTService.searchVehicles($rootScope.params).then(function (response) {

                    $scope.result_items = $rootScope.result_items = response.data.data.filter_types;

                    var lookup = [];

                    $scope.result_items.forEach(function (el) {
                        lookup[el.name] = el.filters;
                    });

                    $scope.items = lookup[$scope.current_filter];

                });
            } else {

                $scope.items = $scope.filter_types[$scope.current_filter].filters;

            }

            $ionicScrollDelegate.scrollTop();
            $scope.show_filter_chooser = true;

        }

        $scope.selectOption = function (current_filter, value) {
            $scope.show_filter_chooser = false;

            if (current_filter != 'TYPE' && current_filter != 'BRAND' && current_filter != 'MODEL') {
                $scope.filter_types[current_filter].selected = value;

                $scope.items = null;
                $scope.show_filters_box = true;

            }
            else {
                $scope.filter_types[current_filter].selected = value;

                switch (current_filter) {
                    case 'TYPE' :
                        if ($scope.filter_types['BRAND'] != null) {
                            $scope.filter_types['BRAND'].selected = null;
                        }
                        if ($scope.filter_types['MODEL'] != null) {
                            $scope.filter_types['MODEL'].selected = null;
                        }
                        break;
                    case 'BRAND' :
                        if ($scope.filter_types['MODEL'] != null) {
                            $scope.filter_types['MODEL'].selected = null;
                        }
                        break;
                }


                $scope.type_name = ($scope.filter_types['TYPE'] != null && $scope.filter_types['TYPE'].selected != null) ? $scope.filter_types['TYPE'].selected.name : null;
                $scope.brand_name = ($scope.filter_types['BRAND'] != null && $scope.filter_types['BRAND'].selected != null) ? $scope.filter_types['BRAND'].selected.name : null;
                $scope.model_name = ($scope.filter_types['MODEL'] != null && $scope.filter_types['MODEL'].selected != null) ? $scope.filter_types['MODEL'].selected.name : null;

                $rootScope.params = {
                    'TYPE[]': [$scope.type_name]
                }

                if ($scope.brand_name != null) {
                    $rootScope.params['BRAND[]'] = [$scope.brand_name];

                    if ($scope.model_name != null) {
                        $rootScope.params['MODEL[]'] = [$scope.model_name];

                    }
                }

                $rootScope.params['PAGE'] = 1;

                $rootScope.params['ORDER_BY'] = $rootScope.currentOrder.order.code;

                for (var filter_type in $scope.filter_types) {
                    if ($scope.filter_types[filter_type] != null) {
                        var filter_name = filter_type + '[]';
                        if ($scope.filter_types[filter_type].selected != null) {
                            $rootScope.params[filter_name] = [$scope.filter_types[filter_type].selected.name];
                        }
                        else {
                            $rootScope.params[filter_name] = null;
                        }
                    }
                }

                PTService.searchVehicles($rootScope.params).then(function (response) {
                    $rootScope.response = response;
                    $rootScope.items_list = response.data.data.result_set;
                    $rootScope.result_filter_types = response.data.data.filter_types;


                    for (var i = 0; i < $rootScope.result_filter_types.length; i++) {
                        $scope.filter_types[$rootScope.result_filter_types[i].name] = $rootScope.result_filter_types[i];

                        for (var j = 0; j < $rootScope.result_filter_types[i].filters.length; j++) {
                            if ($rootScope.result_filter_types[i].filters[j].status == true) {
                                $scope.filter_types[$rootScope.result_filter_types[i].name].selected = $rootScope.result_filter_types[i].filters[j];
                            }
                        }
                    }

                    $rootScope.filter_types = $scope.filter_types;

                    $state.go($state.current, {}, {reload: true});

                    $scope.items = null;
                    $scope.header_title = "Actualizar listado";
                    $scope.show_filters_box = true;

                });


            }


        }

        $scope.closeFilters = function () {
            $scope.show_filter_chooser = false;
            $scope.header_title = "Actualizar listado";

            $scope.items = null;

            $scope.show_filters_box = true;

        };

        $scope.filterDisabled = function (filter, parent_filter) {
            return ($scope.filter_types[parent_filter] == null || $scope.filter_types[parent_filter].selected == null);
        };

        $scope.filterSelected = function (filter) {
            return $scope.filter_types[filter] != null && $scope.filter_types[filter].selected != null;
        };

        $scope.resetFilters = function (filter) {

            if (filter != null) {

                switch (filter) {
                    case 'BRAND' :
                        $scope.filter_types['BRAND'] = $scope.filter_types['MODEL'] = null;
                        $rootScope.params['BRAND[]'] = $rootScope.params['MODEL[]'] = null;
                        break;
                    case 'MODEL' :
                        $scope.filter_types['MODEL'] = null;
                        $rootScope.params['MODEL[]'] = null;
                        break;
                    case 'TYPE' :
                        $scope.filter_types['TYPE'] = $scope.filter_types['BRAND'] = $scope.filter_types['MODEL'] = null;
                        $rootScope.params['TYPE[]'] = $rootScope.params['BRAND[]'] = $rootScope.params['MODEL[]'] = null;
                        break;
                    default :
                        $scope.filter_types[filter].selected = null;
                }


                if (filter == 'BRAND' || filter == 'MODEL') {

                    $rootScope.params['PAGE'] = 1;


                    //verify all current filters by added property 'selected'
                    for (var filter_type in $scope.filter_types) {
                        if ($scope.filter_types[filter_type] != null) {
                            var filter_name = filter_type + '[]';
                            if ($scope.filter_types[filter_type].selected != null) {
                                $rootScope.params[filter_name] = [$scope.filter_types[filter_type].selected.name];
                            }
                            else {
                                $rootScope.params[filter_name] = null;
                            }
                        }
                    }


                    PTService.searchVehicles($rootScope.params).then(function (response) {
                        $rootScope.response = response;

                        $rootScope.items_list = $scope.items_list = response.data.data.result_set;

                        $rootScope.result_filter_types = response.data.data.filter_types;

                        for (var i = 0; i < $rootScope.result_filter_types.length; i++) {
                            $scope.filter_types[$rootScope.result_filter_types[i].name] = $rootScope.result_filter_types[i];

                            for (var j = 0; j < $rootScope.result_filter_types[i].filters.length; j++) {
                                if ($rootScope.result_filter_types[i].filters[j].status == true) {
                                    $scope.filter_types[$rootScope.result_filter_types[i].name].selected = $rootScope.result_filter_types[i].filters[j];
                                }
                            }
                        }

                        $rootScope.filter_types = $scope.filter_types;

                        $state.go($state.current, {}, {reload: true});

                        $scope.items = null;
                        $scope.show_filters_box = true;

                    });

                }
                else if (filter == 'TYPE') {
                    $scope.showFilterChooser('TYPE');
                }

            } else {
                angular.forEach($scope.filter_types, function (value, key) {
                    if (value != null && key != 'TYPE') {
                        value.selected = null;
                    }
                });

                $scope.filter_types['TYPE'].selected = $scope.filter_types['TYPE'].filters[0];
                $scope.filter_types['TYPE'].selected.status = true;

                $scope.price.current = $scope.price.max;
                $scope.mileage.current = $scope.mileage.max;
                $scope.year.current = $scope.year.max;


                for (var filter_type in $scope.filter_types) {
                    if ($scope.filter_types[filter_type] != null) {
                        var filter_name = filter_type + '[]';
                        if ($scope.filter_types[filter_type].selected != null) {
                            $rootScope.params[filter_name] = [$scope.filter_types[filter_type].selected.name];
                        }
                        else {
                            $rootScope.params[filter_name] = null;
                        }
                    }
                }

                $rootScope.params['PAGE'] = 1;


                PTService.searchVehicles($rootScope.params).then(function (response) {
                    $rootScope.response = response;

                    $rootScope.items_list = $scope.items_list = response.data.data.result_set;

                    $rootScope.result_filter_types = response.data.data.filter_types;

                    for (var i = 0; i < $rootScope.result_filter_types.length; i++) {
                        $scope.filter_types[$rootScope.result_filter_types[i].name] = $rootScope.result_filter_types[i];

                        for (var j = 0; j < $rootScope.result_filter_types[i].filters.length; j++) {
                            if ($rootScope.result_filter_types[i].filters[j].status == true) {
                                $scope.filter_types[$rootScope.result_filter_types[i].name].selected = $rootScope.result_filter_types[i].filters[j];
                            }
                        }
                    }

                    $rootScope.filter_types = $scope.filter_types;

                    $state.go($state.current, {}, {reload: true});

                    $scope.items = null;
                    $scope.show_filters_box = true;

                });

            }
        };

    })

    // [END] SIDE FILTERS CONTROLLER

    // SIDE SORTERS CONTROLLER

    .controller('SideSortersCtrl', function ($scope, $stateParams, $location, $rootScope, PTService, $state, $ionicPlatform) {
        $ionicPlatform.ready(function () {
            if (typeof analytics !== 'undefined') {
                analytics.trackView('Side Sorter Screen ' + $rootScope.analyticsUserId);
            }
        });
        $scope.orders = [
            {name: 'Precio', code: 'PRICE'},
            {name: 'Destacado', code: 'HIGHLIGHTED'},
            {name: 'Ciudad', code: 'CITY'},
            {name: 'Publicado', code: 'PUBLISHED'},
            {name: 'Año', code: 'YEAR'},
            {name: 'Kilometraje', code: 'MILEAGE'}
        ];

        $scope.header_title = "Ordenar listado"

        if ($rootScope.currentOrder == null) {
            $scope.currentOrder = $rootScope.currentOrder = {};
            $scope.currentOrder.order = $rootScope.currentOrder.order = {name: 'Destacado', code: 'HIGHLIGHTED'};
            $scope.currentOrder.type = $rootScope.currentOrder.type = true;
        }

        $scope.setOrder = function (order) {

            $scope.$broadcast('scroll.scrollTop');

            $rootScope.currentOrder.order = order;

            var orders = {false: 'ASC', true: 'DESC'};

            var params = {};
            _.each($rootScope.params, function (value, key) {
                if (value !== 'ASC' && value !== 'DESC') {
                    params[key] = value;
                }
            });
            $rootScope.params = params;

            if ($rootScope.currentOrder.order.code == order.code) {
                $rootScope.currentOrder.type = !$rootScope.currentOrder.type;
                var param_type = orders[$rootScope.currentOrder.type]
                $rootScope.params['' + param_type] = param_type;
            }
            else {
                $rootScope.currentOrder.type = true;
                $rootScope.params[orders[true]] = orders[true];
            }

            $rootScope.params['ORDER_BY'] = $rootScope.currentOrder.order.code;
            $rootScope.params['PAGE'] = 1;


            $scope.currentOrder = $rootScope.currentOrder;


            PTService.searchVehicles($rootScope.params).then(function (response) {

                $rootScope.response = response;

                $rootScope.items_list = response.data.data.result_set;

                $rootScope.result_filter_types = response.data.data.filter_types;

                for (var i = 0; i < $rootScope.result_filter_types.length; i++) {
                    $scope.filter_types[$rootScope.result_filter_types[i].name] = $rootScope.result_filter_types[i];

                    for (var j = 0; j < $rootScope.result_filter_types[i].filters.length; j++) {
                        if ($rootScope.result_filter_types[i].filters[j].status == true) {
                            $scope.filter_types[$rootScope.result_filter_types[i].name].selected = $rootScope.result_filter_types[i].filters[j];
                        }
                    }
                }

                $rootScope.filter_types = $scope.filter_types;

                $state.go($state.current, {}, {reload: true});
            });

        };

    })

// [END] SIDE SORTERS CONTROLLER

// DETAILS CONTROLLER

    .controller('DetailsCtrl', function ($scope, $stateParams, $location, $rootScope, $ionicModal, PTService, $ionicSideMenuDelegate, $ionicScrollDelegate, $ionicPopup, $ionicPlatform) {
        $ionicPlatform.ready(function () {
            if (typeof analytics !== 'undefined') {
                analytics.trackView('Detail Screen ' + $rootScope.analyticsUserId);
            }
        });
        $scope.vehicle = $rootScope.vehicle;
        $scope.dealer = $rootScope.dealer;
        $scope.dealer_tag = $rootScope.dealer_tag;
        $scope.submitted = false;
        $scope.form = {};
        $scope.slide_selected = 0;

        $scope.image_width = 800;
        $scope.image_height = 600;

        $scope.header_title = $scope.vehicle.attributes['BRAND'].value[0] + ' ' + $scope.vehicle.attributes['MODEL'].value[0];
        $scope.header_subtitle = $scope.vehicle.attributes['YEAR'].value[0] + ' ' + $scope.vehicle.attributes['SUBTYPE'].value[0];

        $scope.leftMenuEnabled = function () {
            return false;
        }
        $scope.rightMenuEnabled = function () {
            return false;
        }

        $scope.goBack = function () {
            history.back();
        };

        $ionicSideMenuDelegate.canDragContent(false);

        $scope.submitted = false;


        $scope.showContactModal = function () {
            $scope.submitted = false;
            if ($scope.form.contactForm != undefined) {
                $scope.form.contactForm.contact_name.$dirty = $scope.form.contactForm.contact_name.$invalid = false;
                $scope.form.contactForm.contact_lastname.$dirty = $scope.form.contactForm.contact_lastname.$invalid = false;
                $scope.form.contactForm.contact_email.$dirty = $scope.form.contactForm.contact_email.$invalid = false;
                $scope.form.contactForm.contact_phone.$dirty = $scope.form.contactForm.contact_phone.$invalid = false;
                $scope.form.contactForm.contact_message.$dirty = $scope.form.contactForm.contact_message.$invalid = false;

                $scope.contact_name = $scope.contact_lastname = $scope.contact_email = $scope.contact_phone = $scope.contact_message = null;
            }
            ;

            $scope.$broadcast('scroll.scrollTop');
            $ionicScrollDelegate.scrollTop();

            if ($scope.contactModal == null) {
                $ionicModal.fromTemplateUrl('partials/modals/_contact.html', {
                    scope: $scope,
                    animation: 'slide-in-down',
                    focusFirstInput: true
                }).then(function (modal) {
                    $scope.contactModal = modal;

                    $scope.contactModal.show();
                });

            } else {
                $scope.contactModal.show();
            }

            $ionicScrollDelegate.scrollTop();

        };

        $scope.openContactModal = function () {

            $scope.contactModal.show();
            $ionicScrollDelegate.scrollTop();

        };

        $scope.closeContactModal = function () {
            $scope.submitted = false;
            $scope.contactModal.hide();
        };
        //Cleanup the modal when we're done with it!
        $scope.$on('$destroy', function () {
            if ($scope.contactModal != null) {
                $scope.contactModal.remove();
            }
        });
        // Execute action on hide modal
        $scope.$on('modal.hidden', function () {
            // Execute action
        });
        // Execute action on remove modal
        $scope.$on('modal.removed', function () {
            // Execute action
        });

        $scope.contact = {
            vehicleId: $scope.vehicle.id,
            dealerId: $scope.vehicle.dealer.id
        };

        $scope.invalidContactField = function (field) {
            if (field.$invalid) field.$dirty = true;
            return field.$invalid;
        }

        $scope.findFirstInvalid = function () {
            for (var key in $scope.form.contactForm) {
                if (key.indexOf("$") !== 0) {
                    if ($scope.form.contactForm[key].$invalid) {
                        return $scope.form.contactForm[key];
                    }
                }
            }
            return null;
        }

        $scope.invalidContactForm = function () {
            var invalid_name, invalid_lastname, invalid_email, invalid_phone, invalid_message;

            invalid_name = $scope.invalidContactField($scope.form.contactForm.contact_name);
            invalid_lastname = $scope.invalidContactField($scope.form.contactForm.contact_lastname);
            invalid_email = $scope.invalidContactField($scope.form.contactForm.contact_email);
            invalid_phone = $scope.invalidContactField($scope.form.contactForm.contact_phone);
            invalid_message = $scope.invalidContactField($scope.form.contactForm.contact_message);

            //var firstInvalid = $scope.findFirstInvalid()
            //if (firstInvalid!=null)
            //	firstInvalid.focus();

            return (invalid_name || invalid_lastname || invalid_email || invalid_phone || invalid_message) && $scope.submitted == true;

        }

        $scope.sendMessage = function (contactForm) {

            $scope.submitted = true;

            if ($scope.invalidContactForm(contactForm)) {

                var alertPopup = $ionicPopup.alert({
                    title: 'Datos no válidos',
                    template: 'Existen errores en los valores ingresados. Por favor, valide los mismos.'
                });

                return false;

            }
            else {


                $scope.params = '{' + '"vehicleId":' + $scope.contact.vehicleId + ','
                + '"dealerId":' + $scope.contact.dealerId + ','
                + '"name":"' + $scope.contact.name + '",'
                + '"lastName":"' + $scope.contact.lastname + '",'
                + '"email":"' + $scope.contact.email + '",'
                + '"telephone":"' + $scope.contact.phone + '",'
                + '"message":"' + $scope.contact.message + '"'
                + '}';

                PTService.sendMessage($scope.params).then(function (response) {
                    var alertPopup = $ionicPopup.alert({
                        title: 'Mensaje enviado',
                        template: 'Muchas gracias por su mensaje. Próximamente, será contactado por el vendedor.'
                    });

                    $scope.contact.name = $scope.contact.lastname = $scope.contact.email = $scope.contact.phone = $scope.contact.message = null;

                    $scope.closeContactModal();
                }, function (response) {
                    var alertPopup = $ionicPopup.alert({
                        title: 'Mensaje no enviado',
                        template: 'Ocurrió un error enviando el mensaje. Por favor, revise los valores ingresados.'
                    });


                });

            }
        }

        $scope.changeSlideIndex = function (index) {
            $scope.slide_selected = index;
        };


        $scope.showGalleryModal = function (selected) {

            if ($scope.galleryModal == null) {

                $ionicModal.fromTemplateUrl('partials/modals/_gallery.html', {
                    scope: $scope,
                    animation: 'slide-in-up'
                }).then(function (modal) {
                    $scope.galleryModal = modal;

                    $scope.galleryModal.show();
                });

            } else {
                $scope.galleryModal.show();
            }

        };

        $scope.openGalleryModal = function () {

            $scope.galleryModal.show();

        };

        $scope.closeGalleryModal = function () {
            $scope.galleryModal.hide();
        };
        //Cleanup the modal when we're done with it!
        $scope.$on('$destroy', function () {
            if ($scope.galleryModal != null) {
                $scope.galleryModal.remove();
            }
        });
        // Execute action on hide modal
        $scope.$on('modal.hidden', function () {
            // Execute action
        });
        // Execute action on remove modal
        $scope.$on('modal.removed', function () {
            // Execute action
        });

    })

// [END] DETAILS CONTROLLER



