angular.module('motorApp.directives', [])

	.directive('imageLoad', [function () {
		return {
			restrict: 'A',
			scope: {
				ngSrc: '@'
			},
			link: function (scope, element, attrs) {

				element.on('error', function () {
					element.attr("src", "img/no-image.png");
					element.removeAttr("ng-src");

					element.parent().find('span').addClass('vehicle-spinner-no-images');

					element.removeClass('vehicle-spinner-hide');
					element.addClass('vehicle-spinner-show');
					element.parent().find('span').remove();
				});

				element.on('load', function () {
					element.removeClass('vehicle-spinner-hide');
					element.addClass('vehicle-spinner-show');
					element.parent().find('span').remove();
				});
				scope.$watch('ngSrc', function (newVal) {
					element.addClass('vehicle-spinner-hide');
					element.parent().append('<span class="spinner-vehicle"></span>');
				});
			}
		}
	}])

	.directive('stopEvent', function () {
		return {
			restrict: 'A',
			link: function (scope, element, attr) {
				element.bind('click', function (e) {
					e.stopPropagation();
				});
			}
		};
	})

	.directive('accessibleForm', function () {
		return {
			restrict: 'A',
			link: function (scope, elem) {

				// set up event handler on the form element
				elem.on('submit', function () {

					// find the first invalid element
					var firstInvalid = angular.element(
						elem[0].querySelector('.ng-invalid'))[0];

					// if we find one, set focus
					if (firstInvalid) {
						firstInvalid.focus();
					}
				});
			}
		};
	})

	.directive('numbersOnly', [function () {
		return {
			restrict: 'A',
			link: function (scope, elm, attrs, ctrl) {
				elm.on('keydown', function (event) {
					if ([8, 13, 27, 37, 38, 39, 40].indexOf(event.which) > -1) {
						// backspace, enter, escape, arrows
						return true;
					} else if (event.which >= 48 && event.which <= 57) {
						// numbers
						return true;
					} else if (event.which >= 96 && event.which <= 105) {
						// numpad number
						return true;
					} else if ([110, 190].indexOf(event.which) > -1) {
						// dot and numpad dot
						return true;
					} else {
						event.preventDefault();

						return false;
					}
				});
			}
		}
	}])

	.directive('validable', [function () {
		return {
			restrict: 'A',
			scope: {
				ngSrc: '@'
			},
			link: function (scope, element, attrs) {

				element.on('change', function () {
					if (this.validity.valid==false) {
						element.parent().parent().find('span').addClass('input-visible');
						element.parent().parent().find('span').removeClass('input-hidden');
					} else {
						element.parent().parent().find('span').removeClass('input-visible');
						element.parent().parent().find('span').addClass('input-hidden');
					}
				});
			}
		}
	}])

;





