'use strict';

var services = angular.module('motorApp.services', []);

services.factory('SettingsService', function ($http, $localStorage) {

    return {
        getHostUrl: function () {
            return $localStorage.settings.host_url.url;
        },
        getDealerTag: function () {
            return $localStorage.settings.dealer_tag;
        },
        getAnalyticsCode: function () {
            return $localStorage.settings.google_analytics.code;
        },
        getAnalyticsUserId: function () {
            return $localStorage.settings.google_analytics.client_id;
        }
    };
});

services.factory('PTService', function ($http, $localStorage, SettingsService, CacheFactory) {

    return {
        searchVehicles: function (params) {
            var searchUrl = SettingsService.getHostUrl() + '/ptx/api/v1/dealer-tag/' + SettingsService.getDealerTag().id + '/search';
            if (!CacheFactory.get('searchVehicleCache')) {
                CacheFactory.createCache('searchVehicleCache', {
                    deleteOnExpire: 'aggressive',
                    maxAge: 120 * 60 * 1000 // 2 hours
                });
            }
            var searchVehicleCache = CacheFactory.get('searchVehicleCache');
            return $http.get(searchUrl, {cache: searchVehicleCache, params: params});
        },
        getVehicleDetails: function (id, params) {
            var vehicleDetailUrl = SettingsService.getHostUrl() + '/ptx/api/v2/vehicle/';
            if (!CacheFactory.get('vehicleDetailCache')) {
                CacheFactory.createCache('vehicleDetailCache', {
                    deleteOnExpire: 'aggressive',
                    maxAge: 1440 * 60 * 1000 // 24 hours
                });
            }
            var vehicleDetailCache = CacheFactory.get('vehicleDetailCache');
            return $http.get(vehicleDetailUrl + id, {cache: vehicleDetailCache, params: params});
        },
        sendMessage: function(params){
            var sendMessageUrl = SettingsService.getHostUrl() + '/ptx/api/v1/dealer/messaging/sendMessage';
            return $http.post(sendMessageUrl, params);
        }
    };
});
